==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabajo</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>El día anterior al evento</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Recuérdame mañana</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recuérdame luego</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutos después</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora después</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas después</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Mañana</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programar Recordatorio</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">El día anterior al evento</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Cerrar</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Recuérdeme mañana</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Recuérdeme más tarde</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Programar recordatorio</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Hoy</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Mañana</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Trabajo</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Vida</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>El día anterior al evento</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Recuérdame mañana</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recuérdame luego</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minutos después</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hora después</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 horas después</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Mañana</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programar Recordatorio</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 a %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
